#
# Copyright (c) 2016 MasterCard International Incorporated
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without modification, are
# permitted provided that the following conditions are met:
#
# Redistributions of source code must retain the above copyright notice, this list of
# conditions and the following disclaimer.
# Redistributions in binary form must reproduce the above copyright notice, this list of
# conditions and the following disclaimer in the documentation and/or other materials
# provided with the distribution.
# Neither the name of the MasterCard International Incorporated nor the names of its
# contributors may be used to endorse or promote products derived from this software
# without specific prior written permission.
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
# EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
# OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT
# SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
# TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
# IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
# IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.
#


require "mastercard/core/model"
require "mastercard/core/baseobject"

module MasterCard
    module API
        module Mastercom
            class CaseFiling < MasterCard::Core::Model::BaseObject
                include MasterCard::Core::Model
                #

                @__store = {
                    '852b65eb-94b4-4715-b24b-7a9dc214c391' => OperationConfig.new("/mastercom/v6/cases", "create", [], []),
                    '327a11d5-ed49-4555-a886-e10ceaaf01bb' => OperationConfig.new("/mastercom/v6/cases/{case-id}/documents", "query", [], ["format","memo"]),
                    '8aa5352f-930f-4d7b-83de-af134e04059f' => OperationConfig.new("/mastercom/v6/cases/imagestatus", "update", [], []),
                    '8650be3f-80f6-482c-b4ca-540edc7fb53e' => OperationConfig.new("/mastercom/v6/cases/status", "update", [], []),
                    'fc603a0d-362b-4845-bfbb-4787d3fde374' => OperationConfig.new("/mastercom/v6/cases/retrieve/claims", "update", [], []),
                    '6a72e1ef-1f07-4ef0-9534-aa1e4fe6f433' => OperationConfig.new("/mastercom/v6/cases/{case-id}", "update", [], []),
                    
                }

                protected

                def self.getOperationConfig(operationUUID)
                    if @__store.key?(operationUUID)
                        return @__store[operationUUID]
                    end
                    raise NotImplementedError.new("Invalid operationUUID supplied:"+ operationUUID)
                end

                def self.getOperationMetadata()
                    return OperationMetadata.new(ResourceConfig.instance.getVersion(), ResourceConfig.instance.getHost(), ResourceConfig.instance.getContext(), ResourceConfig.instance.getJsonNative(), ResourceConfig.instance.getContentTypeOverride())
                end

                public


                def self.create(mapObj)
                    #
                    #Creates object of type CaseFiling
                    #
                    #@param Dict mapObj, containing the required parameters to create a new object
                    #@return [CaseFiling] of the response of created instance.
                    #@raise [APIException] an exception from the response status
                    return self.execute("852b65eb-94b4-4715-b24b-7a9dc214c391", CaseFiling.new(mapObj))
                end












                def self.retrieveDocumentation(criteria)
                    #
                    #Query objects of type CaseFiling by id and optional criteria
                    #@param [Dict] criteria
                    #@return [CaseFiling] object representing the response.
                    #@raise [APIException] an exception from the response status
                    #

                    return self.execute("327a11d5-ed49-4555-a886-e10ceaaf01bb",CaseFiling.new(criteria))
                end



                def caseFilingImageStatus
                    #
                    #Updates an object of type CaseFiling
                    #
                    #@return [CaseFiling] object representing the response.
                    #@raise [APIException] an exception from the response status
                    #
                    return self.class.execute("8aa5352f-930f-4d7b-83de-af134e04059f",self)
                end








                def caseFilingStatus
                    #
                    #Updates an object of type CaseFiling
                    #
                    #@return [CaseFiling] object representing the response.
                    #@raise [APIException] an exception from the response status
                    #
                    return self.class.execute("8650be3f-80f6-482c-b4ca-540edc7fb53e",self)
                end








                def retrieve
                    #
                    #Updates an object of type CaseFiling
                    #
                    #@return [CaseFiling] object representing the response.
                    #@raise [APIException] an exception from the response status
                    #
                    return self.class.execute("fc603a0d-362b-4845-bfbb-4787d3fde374",self)
                end








                def update
                    #
                    #Updates an object of type CaseFiling
                    #
                    #@return [CaseFiling] object representing the response.
                    #@raise [APIException] an exception from the response status
                    #
                    return self.class.execute("6a72e1ef-1f07-4ef0-9534-aa1e4fe6f433",self)
                end







            end
        end
    end
end







