#
# Copyright (c) 2016 MasterCard International Incorporated
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without modification, are
# permitted provided that the following conditions are met:
#
# Redistributions of source code must retain the above copyright notice, this list of
# conditions and the following disclaimer.
# Redistributions in binary form must reproduce the above copyright notice, this list of
# conditions and the following disclaimer in the documentation and/or other materials
# provided with the distribution.
# Neither the name of the MasterCard International Incorporated nor the names of its
# contributors may be used to endorse or promote products derived from this software
# without specific prior written permission.
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
# EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
# OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT
# SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
# TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
# IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
# IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.
#


require "mastercard/core/model"
require "mastercard/core/baseobject"

module MasterCard
    module API
        module Mastercom
            class Chargebacks < MasterCard::Core::Model::BaseObject
                include MasterCard::Core::Model
                #

                @__store = {
                    'a4ca54dc-ba89-418f-b38d-699f32bef089' => OperationConfig.new("/mastercom/v6/chargebacks/acknowledge", "update", [], []),
                    'a96bd620-a49d-4222-8065-c0410d980fc7' => OperationConfig.new("/mastercom/v6/claims/{claim-id}/chargebacks", "create", [], []),
                    'c6cc9f7b-e279-40ce-a9d2-dda490d12825' => OperationConfig.new("/mastercom/v6/claims/{claim-id}/chargebacks/{chargeback-id}/reversal", "create", [], []),
                    '7c26acb2-a9cd-4c05-8314-7147dce0906a' => OperationConfig.new("/mastercom/v6/claims/{claim-id}/chargebacks/{chargeback-id}/documents", "query", [], ["format"]),
                    '598dd945-f711-4cf9-8df1-a09579998850' => OperationConfig.new("/mastercom/v6/claims/{claim-id}/chargebacks/loaddataforchargebacks", "create", [], []),
                    'f48cf894-b6b3-454c-b215-94eddabb931a' => OperationConfig.new("/mastercom/v6/chargebacks/imagestatus", "update", [], []),
                    '709d18c2-9fb9-4a29-9cd7-1dd39f26dd64' => OperationConfig.new("/mastercom/v6/chargebacks/status", "update", [], []),
                    '1e0acfea-d280-4feb-82e7-287e7c8edfc3' => OperationConfig.new("/mastercom/v6/claims/{claim-id}/chargebacks/{chargeback-id}", "update", [], []),
                    
                }

                protected

                def self.getOperationConfig(operationUUID)
                    if @__store.key?(operationUUID)
                        return @__store[operationUUID]
                    end
                    raise NotImplementedError.new("Invalid operationUUID supplied:"+ operationUUID)
                end

                def self.getOperationMetadata()
                    return OperationMetadata.new(ResourceConfig.instance.getVersion(), ResourceConfig.instance.getHost(), ResourceConfig.instance.getContext(), ResourceConfig.instance.getJsonNative(), ResourceConfig.instance.getContentTypeOverride())
                end

                public



                def acknowledgeReceivedChargebacks
                    #
                    #Updates an object of type Chargebacks
                    #
                    #@return [Chargebacks] object representing the response.
                    #@raise [APIException] an exception from the response status
                    #
                    return self.class.execute("a4ca54dc-ba89-418f-b38d-699f32bef089",self)
                end







                def self.create(mapObj)
                    #
                    #Creates object of type Chargebacks
                    #
                    #@param Dict mapObj, containing the required parameters to create a new object
                    #@return [Chargebacks] of the response of created instance.
                    #@raise [APIException] an exception from the response status
                    return self.execute("a96bd620-a49d-4222-8065-c0410d980fc7", Chargebacks.new(mapObj))
                end







                def self.createReversal(mapObj)
                    #
                    #Creates object of type Chargebacks
                    #
                    #@param Dict mapObj, containing the required parameters to create a new object
                    #@return [Chargebacks] of the response of created instance.
                    #@raise [APIException] an exception from the response status
                    return self.execute("c6cc9f7b-e279-40ce-a9d2-dda490d12825", Chargebacks.new(mapObj))
                end












                def self.retrieveDocumentation(criteria)
                    #
                    #Query objects of type Chargebacks by id and optional criteria
                    #@param [Dict] criteria
                    #@return [Chargebacks] object representing the response.
                    #@raise [APIException] an exception from the response status
                    #

                    return self.execute("7c26acb2-a9cd-4c05-8314-7147dce0906a",Chargebacks.new(criteria))
                end


                def self.getPossibleValueListsForCreate(mapObj)
                    #
                    #Creates object of type Chargebacks
                    #
                    #@param Dict mapObj, containing the required parameters to create a new object
                    #@return [Chargebacks] of the response of created instance.
                    #@raise [APIException] an exception from the response status
                    return self.execute("598dd945-f711-4cf9-8df1-a09579998850", Chargebacks.new(mapObj))
                end








                def chargebacksImageStatus
                    #
                    #Updates an object of type Chargebacks
                    #
                    #@return [Chargebacks] object representing the response.
                    #@raise [APIException] an exception from the response status
                    #
                    return self.class.execute("f48cf894-b6b3-454c-b215-94eddabb931a",self)
                end








                def chargebacksStatus
                    #
                    #Updates an object of type Chargebacks
                    #
                    #@return [Chargebacks] object representing the response.
                    #@raise [APIException] an exception from the response status
                    #
                    return self.class.execute("709d18c2-9fb9-4a29-9cd7-1dd39f26dd64",self)
                end








                def update
                    #
                    #Updates an object of type Chargebacks
                    #
                    #@return [Chargebacks] object representing the response.
                    #@raise [APIException] an exception from the response status
                    #
                    return self.class.execute("1e0acfea-d280-4feb-82e7-287e7c8edfc3",self)
                end







            end
        end
    end
end







