#
# Copyright (c) 2016 MasterCard International Incorporated
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without modification, are
# permitted provided that the following conditions are met:
#
# Redistributions of source code must retain the above copyright notice, this list of
# conditions and the following disclaimer.
# Redistributions in binary form must reproduce the above copyright notice, this list of
# conditions and the following disclaimer in the documentation and/or other materials
# provided with the distribution.
# Neither the name of the MasterCard International Incorporated nor the names of its
# contributors may be used to endorse or promote products derived from this software
# without specific prior written permission.
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
# EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
# OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT
# SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
# TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
# IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
# IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.
#


require "mastercard/core/model"
require "mastercard/core/baseobject"

module MasterCard
    module API
        module Mastercom
            class ChargebacksDebitMasterCardAndEuropeDualAcquirer < MasterCard::Core::Model::BaseObject
                include MasterCard::Core::Model
                #

                @__store = {
                    '551f2e3e-f99b-430b-91df-2303e6487e0c' => OperationConfig.new("/mastercom/v6/chargebacks/debitmc/acknowledge", "update", [], []),
                    'd73251c2-0ee1-421c-bb94-79734a3155a5' => OperationConfig.new("/mastercom/v6/claims/{claim-id}/chargebacks/debitmc", "create", [], []),
                    'a3b6f20d-cb3a-428a-a82f-a81b43d55cdb' => OperationConfig.new("/mastercom/v6/claims/{claim-id}/chargebacks/debitmc/{chargeback-id}/reversal", "create", [], []),
                    '24a1f0a6-2baa-4cfb-871e-6448e9fb4dd8' => OperationConfig.new("/mastercom/v6/claims/{claim-id}/chargebacks/debitmc/{chargeback-id}/documents", "query", [], ["format"]),
                    '3d626b5f-0326-4866-b8da-1501b549a249' => OperationConfig.new("/mastercom/v6/chargebacks/debitmc/imagestatus", "update", [], []),
                    'd89c4a9e-bf03-4004-89c5-10dfcf1a693c' => OperationConfig.new("/mastercom/v6/chargebacks/debitmc/status", "update", [], []),
                    'bc09e5e2-d1e5-47d2-a5ce-0bdf785a2fb1' => OperationConfig.new("/mastercom/v6/claims/{claim-id}/chargebacks/debitmc/{chargeback-id}", "update", [], []),
                    
                }

                protected

                def self.getOperationConfig(operationUUID)
                    if @__store.key?(operationUUID)
                        return @__store[operationUUID]
                    end
                    raise NotImplementedError.new("Invalid operationUUID supplied:"+ operationUUID)
                end

                def self.getOperationMetadata()
                    return OperationMetadata.new(ResourceConfig.instance.getVersion(), ResourceConfig.instance.getHost(), ResourceConfig.instance.getContext(), ResourceConfig.instance.getJsonNative(), ResourceConfig.instance.getContentTypeOverride())
                end

                public



                def acknowledgeReceivedChargebacks
                    #
                    #Updates an object of type ChargebacksDebitMasterCardAndEuropeDualAcquirer
                    #
                    #@return [ChargebacksDebitMasterCardAndEuropeDualAcquirer] object representing the response.
                    #@raise [APIException] an exception from the response status
                    #
                    return self.class.execute("551f2e3e-f99b-430b-91df-2303e6487e0c",self)
                end







                def self.create(mapObj)
                    #
                    #Creates object of type ChargebacksDebitMasterCardAndEuropeDualAcquirer
                    #
                    #@param Dict mapObj, containing the required parameters to create a new object
                    #@return [ChargebacksDebitMasterCardAndEuropeDualAcquirer] of the response of created instance.
                    #@raise [APIException] an exception from the response status
                    return self.execute("d73251c2-0ee1-421c-bb94-79734a3155a5", ChargebacksDebitMasterCardAndEuropeDualAcquirer.new(mapObj))
                end







                def self.createReversal(mapObj)
                    #
                    #Creates object of type ChargebacksDebitMasterCardAndEuropeDualAcquirer
                    #
                    #@param Dict mapObj, containing the required parameters to create a new object
                    #@return [ChargebacksDebitMasterCardAndEuropeDualAcquirer] of the response of created instance.
                    #@raise [APIException] an exception from the response status
                    return self.execute("a3b6f20d-cb3a-428a-a82f-a81b43d55cdb", ChargebacksDebitMasterCardAndEuropeDualAcquirer.new(mapObj))
                end












                def self.retrieveDocumentation(criteria)
                    #
                    #Query objects of type ChargebacksDebitMasterCardAndEuropeDualAcquirer by id and optional criteria
                    #@param [Dict] criteria
                    #@return [ChargebacksDebitMasterCardAndEuropeDualAcquirer] object representing the response.
                    #@raise [APIException] an exception from the response status
                    #

                    return self.execute("24a1f0a6-2baa-4cfb-871e-6448e9fb4dd8",ChargebacksDebitMasterCardAndEuropeDualAcquirer.new(criteria))
                end



                def chargebacksImageStatus
                    #
                    #Updates an object of type ChargebacksDebitMasterCardAndEuropeDualAcquirer
                    #
                    #@return [ChargebacksDebitMasterCardAndEuropeDualAcquirer] object representing the response.
                    #@raise [APIException] an exception from the response status
                    #
                    return self.class.execute("3d626b5f-0326-4866-b8da-1501b549a249",self)
                end








                def chargebacksStatus
                    #
                    #Updates an object of type ChargebacksDebitMasterCardAndEuropeDualAcquirer
                    #
                    #@return [ChargebacksDebitMasterCardAndEuropeDualAcquirer] object representing the response.
                    #@raise [APIException] an exception from the response status
                    #
                    return self.class.execute("d89c4a9e-bf03-4004-89c5-10dfcf1a693c",self)
                end








                def update
                    #
                    #Updates an object of type ChargebacksDebitMasterCardAndEuropeDualAcquirer
                    #
                    #@return [ChargebacksDebitMasterCardAndEuropeDualAcquirer] object representing the response.
                    #@raise [APIException] an exception from the response status
                    #
                    return self.class.execute("bc09e5e2-d1e5-47d2-a5ce-0bdf785a2fb1",self)
                end







            end
        end
    end
end







