#
# Copyright (c) 2016 MasterCard International Incorporated
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without modification, are
# permitted provided that the following conditions are met:
#
# Redistributions of source code must retain the above copyright notice, this list of
# conditions and the following disclaimer.
# Redistributions in binary form must reproduce the above copyright notice, this list of
# conditions and the following disclaimer in the documentation and/or other materials
# provided with the distribution.
# Neither the name of the MasterCard International Incorporated nor the names of its
# contributors may be used to endorse or promote products derived from this software
# without specific prior written permission.
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
# EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
# OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT
# SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
# TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
# IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
# IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.
#


require "mastercard/core/model"
require "mastercard/core/baseobject"

module MasterCard
    module API
        module Mastercom
            class Retrievals < MasterCard::Core::Model::BaseObject
                include MasterCard::Core::Model
                #

                @__store = {
                    '2ea62802-968c-4849-89c0-36dd722292a8' => OperationConfig.new("/mastercom/v6/claims/{claim-id}/retrievalrequests/{request-id}/fulfillments", "create", [], []),
                    'ae27698c-326c-4ab4-97b9-e4d943d07700' => OperationConfig.new("/mastercom/v6/claims/{claim-id}/retrievalrequests", "create", [], []),
                    '3433bb2e-a862-4c7b-998e-e0383149b5c1' => OperationConfig.new("/mastercom/v6/claims/{claim-id}/retrievalrequests/loaddataforretrievalrequests", "query", [], []),
                    'abd937f5-a369-4d54-affa-11ad9dc41bed' => OperationConfig.new("/mastercom/v6/claims/{claim-id}/retrievalrequests/{request-id}/documents", "query", [], ["format"]),
                    'f33b97f8-fa62-44b6-af19-31f76ce0975f' => OperationConfig.new("/mastercom/v6/claims/{claim-id}/retrievalrequests/{request-id}/fulfillments/response", "create", [], []),
                    'c2be8087-eed2-4987-ae7a-b23a67804389' => OperationConfig.new("/mastercom/v6/retrievalrequests/imagestatus", "update", [], []),
                    '24de8e0b-a150-4897-90b3-c912ff2fd463' => OperationConfig.new("/mastercom/v6/retrievalrequests/status", "update", [], []),
                    
                }

                protected

                def self.getOperationConfig(operationUUID)
                    if @__store.key?(operationUUID)
                        return @__store[operationUUID]
                    end
                    raise NotImplementedError.new("Invalid operationUUID supplied:"+ operationUUID)
                end

                def self.getOperationMetadata()
                    return OperationMetadata.new(ResourceConfig.instance.getVersion(), ResourceConfig.instance.getHost(), ResourceConfig.instance.getContext(), ResourceConfig.instance.getJsonNative(), ResourceConfig.instance.getContentTypeOverride())
                end

                public


                def self.acquirerFulfillARequest(mapObj)
                    #
                    #Creates object of type Retrievals
                    #
                    #@param Dict mapObj, containing the required parameters to create a new object
                    #@return [Retrievals] of the response of created instance.
                    #@raise [APIException] an exception from the response status
                    return self.execute("2ea62802-968c-4849-89c0-36dd722292a8", Retrievals.new(mapObj))
                end







                def self.create(mapObj)
                    #
                    #Creates object of type Retrievals
                    #
                    #@param Dict mapObj, containing the required parameters to create a new object
                    #@return [Retrievals] of the response of created instance.
                    #@raise [APIException] an exception from the response status
                    return self.execute("ae27698c-326c-4ab4-97b9-e4d943d07700", Retrievals.new(mapObj))
                end












                def self.getPossibleValueListsForCreate(criteria)
                    #
                    #Query objects of type Retrievals by id and optional criteria
                    #@param [Dict] criteria
                    #@return [Retrievals] object representing the response.
                    #@raise [APIException] an exception from the response status
                    #

                    return self.execute("3433bb2e-a862-4c7b-998e-e0383149b5c1",Retrievals.new(criteria))
                end







                def self.getDocumentation(criteria)
                    #
                    #Query objects of type Retrievals by id and optional criteria
                    #@param [Dict] criteria
                    #@return [Retrievals] object representing the response.
                    #@raise [APIException] an exception from the response status
                    #

                    return self.execute("abd937f5-a369-4d54-affa-11ad9dc41bed",Retrievals.new(criteria))
                end


                def self.issuerRespondToFulfillment(mapObj)
                    #
                    #Creates object of type Retrievals
                    #
                    #@param Dict mapObj, containing the required parameters to create a new object
                    #@return [Retrievals] of the response of created instance.
                    #@raise [APIException] an exception from the response status
                    return self.execute("f33b97f8-fa62-44b6-af19-31f76ce0975f", Retrievals.new(mapObj))
                end








                def retrievalFullfilmentImageStatus
                    #
                    #Updates an object of type Retrievals
                    #
                    #@return [Retrievals] object representing the response.
                    #@raise [APIException] an exception from the response status
                    #
                    return self.class.execute("c2be8087-eed2-4987-ae7a-b23a67804389",self)
                end








                def retrievalFullfilmentStatus
                    #
                    #Updates an object of type Retrievals
                    #
                    #@return [Retrievals] object representing the response.
                    #@raise [APIException] an exception from the response status
                    #
                    return self.class.execute("24de8e0b-a150-4897-90b3-c912ff2fd463",self)
                end







            end
        end
    end
end







