#
# Copyright (c) 2016 MasterCard International Incorporated
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without modification, are
# permitted provided that the following conditions are met:
#
# Redistributions of source code must retain the above copyright notice, this list of
# conditions and the following disclaimer.
# Redistributions in binary form must reproduce the above copyright notice, this list of
# conditions and the following disclaimer in the documentation and/or other materials
# provided with the distribution.
# Neither the name of the MasterCard International Incorporated nor the names of its
# contributors may be used to endorse or promote products derived from this software
# without specific prior written permission.
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
# EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
# OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT
# SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
# TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
# IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
# IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.
#


require "mastercard/core/model"
require "mastercard/core/baseobject"

module MasterCard
    module API
        module Mastercom
            class RetrievalsDebitMasterCardAndEuropeDualAcquirer < MasterCard::Core::Model::BaseObject
                include MasterCard::Core::Model
                #

                @__store = {
                    '3e776b9e-a523-464a-bca8-6c864bc997d5' => OperationConfig.new("/mastercom/v6/claims/{claim-id}/retrievalrequests/debitmc/{request-id}/fulfillments", "create", [], []),
                    'f9ed9ce3-932e-49d9-8be7-e9f0efee301d' => OperationConfig.new("/mastercom/v6/claims/{claim-id}/retrievalrequests/debitmc", "create", [], []),
                    'e1e58ef2-4790-4ba4-afbb-acff59f08965' => OperationConfig.new("/mastercom/v6/claims/{claim-id}/retrievalrequests/debitmc/{request-id}/documents", "query", [], ["format"]),
                    'a0a85d7a-3c1a-48ac-a325-d1871059a728' => OperationConfig.new("/mastercom/v6/claims/{claim-id}/retrievalrequests/debitmc/{request-id}/fulfillments/response", "create", [], []),
                    'b9b23df9-beba-418d-8860-a4f366e93af1' => OperationConfig.new("/mastercom/v6/retrievalrequests/debitmc/imagestatus", "update", [], []),
                    '394df995-8759-46ef-9191-e37a1986ca67' => OperationConfig.new("/mastercom/v6/retrievalrequests/debitmc/status", "update", [], []),
                    
                }

                protected

                def self.getOperationConfig(operationUUID)
                    if @__store.key?(operationUUID)
                        return @__store[operationUUID]
                    end
                    raise NotImplementedError.new("Invalid operationUUID supplied:"+ operationUUID)
                end

                def self.getOperationMetadata()
                    return OperationMetadata.new(ResourceConfig.instance.getVersion(), ResourceConfig.instance.getHost(), ResourceConfig.instance.getContext(), ResourceConfig.instance.getJsonNative(), ResourceConfig.instance.getContentTypeOverride())
                end

                public


                def self.acquirerFulfillARequest(mapObj)
                    #
                    #Creates object of type RetrievalsDebitMasterCardAndEuropeDualAcquirer
                    #
                    #@param Dict mapObj, containing the required parameters to create a new object
                    #@return [RetrievalsDebitMasterCardAndEuropeDualAcquirer] of the response of created instance.
                    #@raise [APIException] an exception from the response status
                    return self.execute("3e776b9e-a523-464a-bca8-6c864bc997d5", RetrievalsDebitMasterCardAndEuropeDualAcquirer.new(mapObj))
                end







                def self.create(mapObj)
                    #
                    #Creates object of type RetrievalsDebitMasterCardAndEuropeDualAcquirer
                    #
                    #@param Dict mapObj, containing the required parameters to create a new object
                    #@return [RetrievalsDebitMasterCardAndEuropeDualAcquirer] of the response of created instance.
                    #@raise [APIException] an exception from the response status
                    return self.execute("f9ed9ce3-932e-49d9-8be7-e9f0efee301d", RetrievalsDebitMasterCardAndEuropeDualAcquirer.new(mapObj))
                end












                def self.getDocumentation(criteria)
                    #
                    #Query objects of type RetrievalsDebitMasterCardAndEuropeDualAcquirer by id and optional criteria
                    #@param [Dict] criteria
                    #@return [RetrievalsDebitMasterCardAndEuropeDualAcquirer] object representing the response.
                    #@raise [APIException] an exception from the response status
                    #

                    return self.execute("e1e58ef2-4790-4ba4-afbb-acff59f08965",RetrievalsDebitMasterCardAndEuropeDualAcquirer.new(criteria))
                end


                def self.issuerRespondToFulfillment(mapObj)
                    #
                    #Creates object of type RetrievalsDebitMasterCardAndEuropeDualAcquirer
                    #
                    #@param Dict mapObj, containing the required parameters to create a new object
                    #@return [RetrievalsDebitMasterCardAndEuropeDualAcquirer] of the response of created instance.
                    #@raise [APIException] an exception from the response status
                    return self.execute("a0a85d7a-3c1a-48ac-a325-d1871059a728", RetrievalsDebitMasterCardAndEuropeDualAcquirer.new(mapObj))
                end








                def retrievalFullfilmentImageStatus
                    #
                    #Updates an object of type RetrievalsDebitMasterCardAndEuropeDualAcquirer
                    #
                    #@return [RetrievalsDebitMasterCardAndEuropeDualAcquirer] object representing the response.
                    #@raise [APIException] an exception from the response status
                    #
                    return self.class.execute("b9b23df9-beba-418d-8860-a4f366e93af1",self)
                end








                def retrievalFullfilmentStatus
                    #
                    #Updates an object of type RetrievalsDebitMasterCardAndEuropeDualAcquirer
                    #
                    #@return [RetrievalsDebitMasterCardAndEuropeDualAcquirer] object representing the response.
                    #@raise [APIException] an exception from the response status
                    #
                    return self.class.execute("394df995-8759-46ef-9191-e37a1986ca67",self)
                end







            end
        end
    end
end







